from setuptools import setup

setup(name='dsnd-abdul',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsnd-abdul'],
      author='abdul',
      zip_safe=False)
